<div class="enable-ai-assistant-container">
  <input class="enabled-check" type="checkbox" id="is-enabled-{{ block_id }}" name="is-enabled" {% if is_enabled %} checked {% endif %}/>
  <label class="enabled-label" for="is-enabled-{{ block_id }}">Enable AI Chat Assistant</label>
</div>
