<div class="{{ block_type }}-block-chat-button-container">
  <button class="ai-chat-button {{ block_type }}-block-chat-button" id="chat-button-{{ block_id }}" data-block-id="{{ block_id }}" type="button">
    <img src="/static/images/icon.svg" class="chat-icon">
    <p>Ask<b>TIM</b> about this {{ block_type }}</p>
  </button>
  <div id="app-root-{{ block_id }}"></div>
</div>
