.enable-ai-assistant-container {
    display: flex;
    align-items: center;
    padding: 16px 0;
    margin-left: 20px;

    .enabled-check {
        min-height: 16px !important;
        width: auto !important;
        margin-right: 8px;
    }

    .enabled-label {
        margin: 0 !important;
        display: block;
        font-weight: 400;
        font-size: 14px;
        font-style: normal;
    }
}
