#app-root {
    width: 450px;
    height: 600px;
}

.video-block-chat-button-container {
    background: whitesmoke;
    box-shadow:
            0 -50px 0 12px whitesmoke,
            -12px 12px 0 0 whitesmoke,
            12px 12px 0 0 whitesmoke,
            0 2px 0 0 whitesmoke;
}

.ai-chat-button {
    all: unset;
    display: flex;
    flex-direction: row;
    position: relative;
    bottom: 70px;
    left: 72%;
    width: fit-content;
    cursor: pointer;
    z-index: 1000;
    padding: 12px 24px;
    justify-content: center;
    align-items: center;
    gap: 8px;
    border-radius: 4px;
    border: 1px solid #B8C2CC;
    background: #FFF;

    p {
        color: #212326;
        font-size: 14px;
        font-style: normal;
        font-weight: 400;
        line-height: 18px;
        margin-bottom: 0 !important;

        b {
            font-size: 16px;
            font-weight: 900;

        }
    }

    .chat-icon {
        width: 24px;
        height: 24px;
    }

    &.video-block-chat-button {
        bottom: 0;
        margin-top: 50px;

        p {
            line-height: 20px;
            margin-right: 20px;
        }
    }

    &:hover {
        border: 1px solid #212326;
        background: #FFF !important;
        box-shadow: none !important;
    }

    &:active {
        border: 1px solid #212326;
        background: #FFF !important;
        box-shadow: none !important;
    }
}

@media screen and (max-width: 768px) {
    .ai-chat-button {
        bottom: 65px;
        left: 62%;

        &.video-block-chat-button {
            margin-top: 10px;
        }
    }
}

@media screen and (max-width: 425px) {
    .ai-chat-button {
        position: unset;
        margin-left: 0;
    }
}

.video {
    margin: 0 0;
}
