
# DO NOT EDIT THIS FILE -- AUTOGENERATED BY PANTS
# Target: src/ol_openedx_chat:ol_openedx_chat_package

from setuptools import setup

setup(**{
    'author': 'MIT Office of Digital Learning',
    'description': 'An Open edX plugin to add Open Learning AI chat aside to xBlocks',
    'entry_points': {
        'xblock_asides.v1': [
            'ol_openedx_chat = ol_openedx_chat.block:OLChatAside',
        ],
        'lms.djangoapp': [
            'ol_openedx_chat = ol_openedx_chat.apps:OLOpenedxChatConfig',
        ],
        'cms.djangoapp': [
            'ol_openedx_chat = ol_openedx_chat.apps:OLOpenedxChatConfig',
        ],
    },
    'include_package_data': True,
    'install_requires': (
        'Django>2.0',
        'XBlock',
        'djangorestframework<4.0.0,>=3.14.0',
        'edx-django-utils>4.0.0',
    ),
    'keywords': 'Python edx',
    'license': 'BSD-3-Clause',
    'name': 'ol-openedx-chat',
    'namespace_packages': (
    ),
    'package_data': {
        'ol_openedx_chat': (
            'static/css/ai_chat.css',
            'static/css/studio.css',
            'static/html/student_view.html',
            'static/html/studio_view.html',
            'static/images/icon.svg',
            'static/js/ai_chat.js',
            'static/js/studio.js',
        ),
    },
    'packages': (
        '',
        'ol_openedx_chat',
        'ol_openedx_chat.settings',
    ),
    'python_requires': '>=3.8',
    'version': '0.2.7',
    'zip_safe': False,
})
